@@ -1,6 +1,4 @@
 /*
- * device-mapper.h
- *
  * Copyright (C) 2001 Sistina Software (UK) Limited.
  *
  * This file is released under the LGPL.
@@ -9,7 +7,7 @@
 #ifndef _LINUX_DEVICE_MAPPER_H
 #define _LINUX_DEVICE_MAPPER_H
 
-#define DM_DIR "device-mapper"
+#define DM_DIR "device-mapper"	/* Slashes not supported */
 #define DM_MAX_TYPE_NAME 16
 #define DM_NAME_LEN 128
 
@@ -17,21 +15,24 @@
 
 struct dm_table;
 struct dm_dev;
-typedef unsigned int offset_t;
+typedef unsigned long offset_t;
+
 
 /*
- * Prototypes for functions of a target
+ * Prototypes for functions for a target
  */
-typedef int (*dm_ctr_fn) (struct dm_table * t, offset_t b, offset_t l,
-			  char *args, void **context);
-typedef void (*dm_dtr_fn) (struct dm_table * t, void *c);
-typedef int (*dm_map_fn) (struct buffer_head * bh, int rw, void *context);
-typedef int (*dm_err_fn) (struct buffer_head *bh, int rw, void *context);
+typedef int (*dm_ctr_fn)(struct dm_table *t, offset_t b, offset_t l,
+			 int argc, char **argv, void **context);
+typedef void (*dm_dtr_fn)(struct dm_table *t, void *c);
+typedef int (*dm_map_fn)(struct buffer_head *bh, int rw, void *context);
+typedef int (*dm_err_fn)(struct buffer_head *bh, int rw, void *context);
 
 
+void dm_error(const char *message);
+
 /*
- * Contructors should call these functions to ensure destination devices 
- * are opened/closed correctly 
+ * Constructors should call these functions to ensure destination devices
+ * are opened/closed correctly
  */
 int dm_table_get_device(struct dm_table *t, const char *path,
 			offset_t start, offset_t len, struct dm_dev **result);
